@@ -144,7 +144,7 @@ command_save (gpointer   callback_data,
           const ID3Tag *id3tag;
 
           id3tag = mm_list_get_nth (MM_LIST (mmaid->list), i);
-          if (g_strfilencmp (id3tag->file, path, leng) != 0)
+          if (g_strfilencmp (id3tag->file, path, leng))
             break;
         }
       g_free (path);
@@ -292,7 +292,7 @@ command_saveas (gpointer   callback_data,
       gchar *utf8str;
 
       utf8str = g_filename_to_utf8 (save_path, -1, NULL, NULL, NULL);
-      if (g_strfilencmp (utf8str, path, g_strlen (utf8str)) == 0)
+      if (!g_strfilencmp (utf8str, path, g_strlen (utf8str)))
         root = g_strdup (save_path);
       g_free (utf8str);
     }
@@ -515,7 +515,7 @@ command_export (gpointer   callback_data,
                   for (j = 0; j < genres; j++)
                     for (k = 0; k < 256; k++)
                       if (genre[j][k]
-                                && g_strcmp (genre[j][k], id3tag->genre) == 0)
+                                    && !g_strcmp (genre[j][k], id3tag->genre))
                         {
                           gnum = k;
                           goto loop;
@@ -912,8 +912,8 @@ command_search_recursive (const gchar *path,
                       {
                         mm_list_show_add
                                 (MM_LIST (MM_DIALOG (dialog)->list), n1);
-                        if (g_strlen (file) > 4 && g_strcasecmp (".mp3",
-                                            file + g_strlen (file) - 4) == 0)
+                        if (g_strlen (file) > 4 && !g_strcasecmp (".mp3",
+                                                file + g_strlen (file) - 4))
                           mm_list_set_active_add
                                 (MM_LIST (MM_DIALOG (dialog)->list), n1, TRUE);
                       }
@@ -1123,7 +1123,7 @@ command_copy (gpointer   callback_data,
                   if (OpenClipboard (GDK_WINDOW_HWND (window->window)))
                     {
                       if (!EmptyClipboard ()
-                                || SetClipboardData (uFormat, hGlobal) == NULL)
+                                    || !SetClipboardData (uFormat, hGlobal))
                         GlobalFree (hGlobal);
                       CloseClipboard ();
                     }
