@@ -131,11 +131,10 @@ genre_dialog_sensitive (void)
 /* ja:項目が編集された */
 static void
 genre_dialog_edited (GtkCellRendererText *cell,
-	                 const gchar         *path_string,
-	                 const gchar         *text,
+                     const gchar         *path_string,
+                     const gchar         *text,
                      gpointer             user_data)
 {
-  gchar *str;
   gint column;
   GtkTreeIter iter;
   GtkTreePath *path;
@@ -144,10 +143,8 @@ genre_dialog_edited (GtkCellRendererText *cell,
   path = gtk_tree_path_new_from_string (path_string);
   gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path);
   gtk_tree_path_free (path);
-  gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, column, &str, -1);
   gtk_list_store_set (store, &iter,
                 column, text && text[0] != '\0' ? g_strdup (text) : NULL, -1);
-  g_free (str);
   gtk_widget_set_sensitive (button4, TRUE);
 }
 
@@ -171,21 +168,18 @@ genre_dialog_clicked_new (GtkWidget *widget,
   g_list_free (glist);
   for (i = 0; i < 256; i++)
     {
-      gchar *str = NULL;
       gint j;
       GtkTreeIter iter;
 
       gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
-      for (j = c; j <= count; j++)
+      for (j = count; j > c; j--)
         {
-          gchar *tmp;
+          gchar *str;
 
-          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, j, &tmp, -1);
+          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, j - 1, &str, -1);
           gtk_list_store_set (store, &iter, j, str, -1);
-          str = tmp;
+          g_free (str);
         }
-      gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, c + 1, &str, -1);
-      gtk_list_store_set (store, &iter, c, str ? g_strdup (str) : NULL, -1);
     }
   renderer = gtk_cell_renderer_text_new ();
   g_signal_connect (renderer, "edited",
@@ -220,20 +214,18 @@ genre_dialog_clicked_delete (GtkWidget *widget,
   g_list_free (glist);
   for (i = 0; i < 256; i++)
     {
-      gchar *str = NULL;
       gint j;
       GtkTreeIter iter;
 
       gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
-      for (j = count - 1; j >= c; j--)
+      for (j = c; j < count; j++)
         {
-          gchar *tmp;
+          gchar *str;
 
-          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, j, &tmp, -1);
+          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, j + 1, &str, -1);
           gtk_list_store_set (store, &iter, j, str, -1);
-          str = tmp;
+          g_free (str);
         }
-      g_free (str);
     }
   gtk_tree_view_remove_column (GTK_TREE_VIEW (tview),
                     gtk_tree_view_get_column (GTK_TREE_VIEW (tview), count));
@@ -262,6 +254,8 @@ genre_dialog_clicked_up (GtkWidget *widget,
       gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
                                         c - 1, &str0, c, &str1, -1);
       gtk_list_store_set (store, &iter, c - 1,  str1, c,  str0, -1);
+      g_free (str0);
+      g_free (str1);
     }
   gtk_tree_view_set_cursor (GTK_TREE_VIEW (tview), path,
             gtk_tree_view_get_column (GTK_TREE_VIEW (tview), c), FALSE);
@@ -290,6 +284,8 @@ genre_dialog_clicked_down (GtkWidget *widget,
       gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
                                         c , &str0, c + 1, &str1, -1);
       gtk_list_store_set (store, &iter, c ,  str1, c + 1,  str0, -1);
+      g_free (str0);
+      g_free (str1);
     }
   gtk_tree_view_set_cursor (GTK_TREE_VIEW (tview), path,
             gtk_tree_view_get_column (GTK_TREE_VIEW (tview), c + 2), FALSE);
@@ -319,11 +315,8 @@ genre_dialog_clicked_ok (GtkWidget *widget,
 
       gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store), &iter, NULL, i);
       for (j = 0; j < genres; j++)
-        {
-          gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
+        gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
                                                         j, &genre[j][i], -1);
-          gtk_list_store_set (store, &iter, j, NULL, -1);
-        }
     }
   for (i = 0; i < genres; i++)
     {
@@ -389,6 +382,7 @@ genre_dialog_key_press (GtkWidget   *widget,
 }
 
 
+/*  ja:ジャンルダイアログ表示                                               */
 void
 genre_dialog (void)
 {
