@@ -23,16 +23,27 @@
 #include "mmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 extern gchar *def_genre_list[256];
 
 
 /******************************************************************************
 *                                                                             *
-* ja:ジャンル関数群                                                           *
+* ja:ジャンルダイアログ関数群                                                 *
 *                                                                             *
 ******************************************************************************/
+/*  ja:ジャンルダイアログ表示                                               */
 void
 genre_dialog (void);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif /* __GENRE_H__ */
