@@ -68,14 +68,16 @@ UINT uFormat = 0;                   /* ja:クリップボード */
 *                                                                             *
 ******************************************************************************/
 static gchar *
-menu_translate (const gchar *path, gpointer func_data)
+menu_translate (const gchar *path,
+                gpointer     func_data)
 {
   return _(path);
 }
 
 
 int
-main (int argc, char *argv[])
+main (int   argc,
+      char *argv[])
 {
   gboolean *arg_files, license = FALSE;
   gchar *section, *key, *utf8str;
